angular.module('services', [])

.factory('PaypalService', function ($q, $ionicPlatform, $filter, $timeout,shopSettings) {


        var init_defer;
        /**
         * Service object
         * @type object
         */
        var service = {
            initPaymentUI: initPaymentUI,
            createPayment: createPayment,
            configuration: configuration,
            onPayPalMobileInit: onPayPalMobileInit,
            makePayment: makePayment
        };


        /**
         * @ngdoc method
         * @name initPaymentUI
         * @methodOf app.PaypalService
         * @description
         * Inits the payapl ui with certain envs. 
         *
         * 
         * @returns {object} Promise paypal ui init done
         */
        function initPaymentUI() {

            init_defer = $q.defer();
            $ionicPlatform.ready().then(function () {

                var clientIDs = {
                    "PayPalEnvironmentProduction": shopSettings.payPalProductionId,
                    "PayPalEnvironmentSandbox": shopSettings.payPalSandboxId
                };
                PayPalMobile.init(clientIDs, onPayPalMobileInit);
            });

            return init_defer.promise;

        }


        /**
         * @ngdoc method
         * @name createPayment
         * @methodOf app.PaypalService
         * @param {string|number} total total sum. Pattern 12.23
         * @param {string} name name of the item in paypal
         * @description
         * Creates a paypal payment object 
         *
         * 
         * @returns {object} PayPalPaymentObject
         */
        function createPayment(total, name) {

            // "Sale  == >  immediate payment
            // "Auth" for payment authorization only, to be captured separately at a later time.
            // "Order" for taking an order, with authorization and capture to be done separately at a later time.
            var payment = new PayPalPayment("" + total, "MXN", "" + name, "Sale");
            return payment;
        }
        /**
         * @ngdoc method
         * @name configuration
         * @methodOf app.PaypalService
         * @description
         * Helper to create a paypal configuration object
         *
         * 
         * @returns {object} PayPal configuration
         */
        function configuration() {
            // for more options see `paypal-mobile-js-helper.js`
            var config = new PayPalConfiguration({defaultUserEmail:shopSettings.paypalDefaultUserEmail,merchantName: shopSettings.payPalShopName,sandboxUserPassword:shopSettings.paypalSandboxUserPassword});
            return config;
        }

        function onPayPalMobileInit() {
            $ionicPlatform.ready().then(function () {
                // must be called
                // use PayPalEnvironmentNoNetwork mode to get look and feel of the flow
                PayPalMobile.prepareToRender(shopSettings.payPalEnv, configuration(), function () {

                    $timeout(function () {
                        init_defer.resolve();
                    });

                });
            });
        }

        /**
         * @ngdoc method
         * @name makePayment
         * @methodOf app.PaypalService
         * @param {string|number} total total sum. Pattern 12.23
         * @param {string} name name of the item in paypal
         * @description
         * Performs a paypal single payment 
         *
         * 
         * @returns {object} Promise gets resolved on successful payment, rejected on error 
         */
        function makePayment(total, name) {
            var defer = $q.defer();
            //total = $filter('number')(total, 2);
            $ionicPlatform.ready().then(function () {
                PayPalMobile.renderSinglePaymentUI(createPayment(total, name), function (result) {
                    $timeout(function () {
                        defer.resolve(result);
                    });
                    console.log(result.response);

                }, function (error) {
                    $timeout(function () {
                        defer.reject(error);
                    });
                });
            });

            return defer.promise;
        }

        return service;
    })
    
.factory('Pedido', function ($q,$rootScope,$http) {

    var Pedido = {};
    var pedido ={};//= JSON.parse(window.localStorage['canasta'] || '[]');
    var horarios=[];

    Pedido.loadHorarios = function () {
        var deffered = $q.defer();
        var url = $rootScope.baseUrl + '&action=get&path=horario{}';
        console.log(url)
        $http.get(url)
        .success(function (d) {
            horarios = d.value;
            deffered.resolve();
        });
        return deffered.promise;
    };

    Pedido.getHorarios=function(){
        return horarios;
    }
    Pedido.getHorarioByIdx=function(idx){
        return horarios[idx];
    };


    Pedido.setPedido = function (semanal,fecha,zona,direccion,telefono,nombre,horario,de,para) {
        pedido.semanal=semanal;
        pedido.fecha=fecha;
        pedido.zona=zona;
        pedido.direccion=direccion;
        pedido.telefono=telefono;
        pedido.nombre=nombre;
        pedido.horario=horario;
        pedido.de=de;
        pedido.para=para;

        console.log(pedido);
    };
    Pedido.getPedido=function(){
        return pedido;
    };
    
    return Pedido;

})
.factory('Carrito', function () {

    var Carrito = {};
    var productos = JSON.parse(window.localStorage['carrito'] || '{"productos":[]}');
    var regalo=undefined;

    Carrito.agregarProducto = function (prod) {

        var encontrado = false;
        for (i = 0; i < productos.productos.length; i++) {
            if (productos.productos[i]._id == prod._id) {
                if (prod.cant === 0) {
                    productos.productos.splice(i, 1);
                } else {
                    productos.productos[i].cant = prod.cant;
                }
                encontrado = true;
            }
        }

        if (encontrado === false) {
            if (prod.cant !== 0) {
                productos.productos.push(prod);

            }
        }
        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.eliminarProducto = function (id) {
        for (i = 0; i < productos["productos"].length; i++) {
            if (productos["productos"][i]._id == id) {
                productos["productos"].splice(i, 1);
            }
        }
        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.actualizarNotas = function (id, notas) {
        for (i = 0; i < productos["productos"].length; i++) {
            if (productos["productos"][i].id == id) {
                productos["productos"][i].notas = notas;
            }
        }
        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.actualizarNotasGenerales = function (notas) {
        productos.notasGenerales = notas;
        console.log(productos);
        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.setDescuento = function (desc) {
        productos.descuento = desc;
        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.getDescuento = function () {
        if (productos.descuento === undefined) {
            productos.descuento = 1;
        }
        return productos.descuento;
    };

    Carrito.vaciarCarrito = function (id) {
        productos = {
            "productos": []
        };

        window.localStorage['carrito'] = JSON.stringify(productos);

    };
    Carrito.getProductos = function () {
        return productos["productos"];
    };
    Carrito.getNotasGenerales = function () {
        return productos["notasGenerales"];
    };
    Carrito.getProductoByID = function (id) {
        for (i = 0; i < productos["productos"].length; i++) {
            if (productos["productos"][i].id == id) {
                return productos["productos"][i];
            }
        }

    };
    Carrito.getTotal = function () {
        var total = 0;
        for (i = 0; i < productos["productos"].length; i++) {
            total += productos["productos"][i].precio._value * productos["productos"][i].cant;
        }
        console.log(total);
        if(productos.descuento){
            if(productos.descuento.descuento){
                total=total-(total*productos.descuento.descuento._value);
            }
            
        }
        console.log(total);


        return total;

    };
    Carrito.removeRegalos=function(){
        for (i = 0; i < productos["productos"].length; i++) {
            if (productos["productos"][i].isRegalo) {
                productos["productos"].splice(i, 1);
            }
        }
        window.localStorage['carrito'] = JSON.stringify(productos);
    }
    Carrito.setRegalo=function(prod){
        regalo=prod;
    }
    Carrito.getRegalo=function(){
        return regalo;
    }

    return Carrito;

})
.factory('Canasta', function () {

    var Canasta = {};
    var productos = JSON.parse(window.localStorage['canasta'] || '[]');
    console.log(productos);
    Canasta.agregarEliminar = function (prod) {

        var encontrado = false;
        for (i = 0; i < productos.length; i++) {
            if (productos[i]._id == prod._id) {
                productos.splice(i, 1);
                encontrado = true;
            }
        }

        if (encontrado === false) {
            prod.cant=1;
            productos.push(prod);
        }

        window.localStorage['canasta'] = JSON.stringify(productos);
        console.log(productos);
        return encontrado;
    };
    Canasta.eliminarProducto = function (id) {
        for (i = 0; i < productos.length; i++) {
            if (productos[i]._id == id) {
                productos.splice(i, 1);
            }
        }
        window.localStorage['canasta'] = JSON.stringify(productos);
    };
    

    Canasta.vaciarCarrito = function (id) {
        productos = [];

        window.localStorage['canasta'] = JSON.stringify(productos);

    };

    Canasta.getProductos = function () {
        return productos;
    };
    
    Canasta.getProductoByID = function (id) {
        for (i = 0; i < productos.length; i++) {
            if (productos[i].id == id) {
                return productos[i];
            }
        }

    };
    Canasta.isAdded=function(id){
        for (i = 0; i < productos.length; i++) {
            if (productos[i]._id == id) {
                return true;
            }
        }
        return false;
    };
    return Canasta;

})
.factory('MensajesService', function ($http, $q, $rootScope) {
    
    var data = [];
    var MensajesService = {};

    MensajesService.async = function () {
        var deffered = $q.defer();
        var usuario = JSON.parse(window.localStorage['usuario']);
        var url=$rootScope.baseUrl + '&action=get&path=cliente('+usuario._id+').mensaje.my_messages';
        console.log(url)
        $http.get(url)
        .success(function (d) {
            data = d.value;
            console.log(data);
            deffered.resolve();


        });
        return deffered.promise;
    };
    MensajesService.dataByID = function (id) {

        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                return data[i];
            }
        }
    };

    MensajesService.data = function () {
        return data;
    };

    return MensajesService;
})
.factory('Zonas', function ($http, $q, $rootScope) {
    
    var data = [];
    var Zonas = {};

    Zonas.async = function () {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=zona{}';
        $http.get(url)
        .success(function (d) {
            data = d.value;

            deffered.resolve();
            
            
        });
        return deffered.promise;
    };
    Zonas.dataByID = function (id) {

        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                return data[i];
            }
        }
    };

    Zonas.data = function () {
        return data;
    };

    return Zonas;
})
.factory('Promocion', function ($http, $q, $rootScope) {
    
    var data = [];
    var Promocion = {};

    Promocion.async = function () {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=promocion{}';
        $http.get(url)
        .success(function (d) {
            data = d.value;
            console.log(data);
            deffered.resolve();


        });
        return deffered.promise;
    };


    Promocion.data = function () {
        return data;
    };

    return Promocion;
})
.factory('ProductosService', function ($http, $q, $rootScope) {
    
    var data = [];
    var ProductosService = {};

    ProductosService.async = function (id) {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=producto{categoria.id:' + id + '}{}';
        console.log(url);
        $http.get(url)
            .success(function (d) {
                data = d.value;
                console.log("1");
                //data.shift();
                deffered.resolve();
            });
        return deffered.promise;
    };
    ProductosService.dataByID = function (id) {
        console.log(data);
        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                console.log(data[i]);
                return data[i];
            }
        }
    };

    ProductosService.data = function () {
        return data;
    };

    return ProductosService;
})
.factory('PaquetesServ', function ($http, $q, $rootScope) {
    
    var data = [];
    var PaquetesServ = {};

    PaquetesServ.async = function (tipo) {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=paquete{tipo._value:'+tipo+'}{}';
        console.log(url);
        $http.get(url)
        .success(function (d) {
            data = d.value;
            deffered.resolve();
        });
        return deffered.promise;
    };
    PaquetesServ.dataByID = function (id) {

        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                return data[i];
            }
        }
        
    };
    

    PaquetesServ.data = function () {
        return data;
    };

    return PaquetesServ;
})
.factory('PedidoSemanal', function ($http, $q, $rootScope) {
    
    var data = [];
    var PedidoSemanal = {};
    var usuario = JSON.parse(window.localStorage['usuario']);
    PedidoSemanal.async = function (id) {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=pedido_semanal{cliente.id:'+usuario._id+'}{}';
        console.log(url);
        $http.get(url)
        .success(function (d) {
            data = d.value;
            deffered.resolve();
        });
        return deffered.promise;
    };
    PedidoSemanal.dataByID = function (id) {

        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                return data[i];
            }
        }
        
    };
    

    PedidoSemanal.data = function () {
        return data;
    };

    return PedidoSemanal;
})
.factory('PedidoSemanal', function ($http, $q, $rootScope) {
    
    var data = [];
    var PedidoSemanal = {};
    var usuario = JSON.parse(window.localStorage['usuario']);
    PedidoSemanal.async = function (id) {
        var deffered = $q.defer();
        var url=$rootScope.baseUrl + '&action=get&path=pedido_semanal{cliente.id:'+usuario._id+'}{}';
        console.log(url);
        $http.get(url)
        .success(function (d) {
            data = d.value;
            deffered.resolve();
        });
        return deffered.promise;
    };
    PedidoSemanal.dataByID = function (id) {

        for (i = 0; i < data.length; i++) {
            if (data[i]._id == id) {
                return data[i];
            }
        }
        
    };
    

    PedidoSemanal.data = function () {
        return data;
    };

    return PedidoSemanal;
})
.factory('Pagos', function ($http, $q, $rootScope,$ionicPopup) {


        
        var data = [];
        var Pagos = {};

        

        Pagos.registrarTarjeta = function (num,nom,ano,mes,ccv,sess) {
            var deffered = $q.defer();


            OpenPay.token.create({
                    "card_number":num,
                    "holder_name":nom,
                    "expiration_year":ano,
                    "expiration_month":mes,
                    "cvv2":ccv

                }, function(response){

                    var usuario = JSON.parse(window.localStorage['usuario']);
                    
                    var token_id = response.data.id;
                    console.log(token_id);
                    var url = $rootScope.baseUrl + '&path=admin(1).pago&action=openpay_register&user_id='+usuario._id
                                +'&name='+nom+'&email='+usuario._user[0].username._value+'&card_token='+token_id
                                +'&device_session_id='+sess+'&save=1';
                    $http.get(url)
                        .success(function (response2) {
                            console.log(response2);
                            if (response2.card_token ) {
                                
                                deffered.resolve(response2);
                            }
                            else{
                                deffered.reject();
                            }
                        }).error(function (error) {
                            console.log(error);
                            
                            deffered.reject(error);
                    }); 
                }, function(response){
                    var desc = response.data.description != undefined ? response.data.description : response.message;
                    alert("ERROR [" + response.status + "] " + desc);
                    deffered.reject();
                });

            return deffered.promise;
        };
        Pagos.cobrar = function (token,sess,amount,desc,id) {
            var deffered = $q.defer();
            var usuario = JSON.parse(window.localStorage['usuario']);
            var url = $rootScope.baseUrl + '&path=admin(1).pago&action=openpay_charge&user_id='+usuario._id
                                +'&card_token='+token+'&device_session_id='
                                +sess+'&amount='+amount+'&description='+desc+'&order_id='+id;

            console.log(url);
            $http.get(url)
                .success(function (response2) {
                    deffered.resolve(response2);
                }).error(function (error) {
                    Bugsnag.notify("Error Pago", "Error en la conexion del pago");
                    deffered.reject(error);
            }); 
            return deffered.promise;
        };
        Pagos.eliminarTarjeta = function (id) {
            var deffered = $q.defer();
            var usuario = JSON.parse(window.localStorage['usuario']);
            var url = $rootScope.baseUrl + '&path=admin(1).pago&action=openpay_delete_card&user_id='+usuario._id
                                +'&card_id='+id;

            console.log(url);
            $http.get(url)
                .success(function (response2) {
                    deffered.resolve(response2);
                }).error(function (error) {
                    deffered.reject(error);
            }); 
            return deffered.promise;
        };

        Pagos.suscribir = function (token,sess,amount,desc,id,fecha_inicio) {
            /*
            para registrar una subscripcion:
                    action openpay_subscription
                    path path to openpay.keys object
                user_id
                card_id | card_token
                amount
                order_id (path de pedido)
                
                repeat_unit
                repeat_every | 
                start_date (ejemplo de formato "2014-01-01")
            */
            var deffered = $q.defer();
            var usuario = JSON.parse(window.localStorage['usuario']);
            var url = $rootScope.baseUrl + '&path=admin(1).pago&action=openpay_subscription&user_id='+usuario._id
                                +'&card_token='+token+'&device_session_id='
                                +sess+'&amount='+amount+'&description='+desc+'&order_id=pedido_semanal('+id+')&repeat_unit=week&repeat_every=1&trial_end_date='+fecha_inicio;

            console.log(url);
            $http.get(url)
                .success(function (response2) {
                    deffered.resolve(response2);
                }).error(function (error) {
                    deffered.reject(error);
            }); 
            return deffered.promise;
        };

        Pagos.getTarjetas=function(){
            var deffered = $q.defer();
            var usuario = JSON.parse(window.localStorage['usuario']);
            var url = $rootScope.baseUrl + '&path=cliente('+usuario._id+').pago.card&action=get';
            console.log(url);
            $http.get(url)
                .success(function (response) {
                    data=response.value;
                    console.log(data);
                    deffered.resolve();
                    
                }).error(function (error) {
                    var alertPopup = $ionicPopup.alert({
                        title: 'ePharmacy',
                        template: 'Ocurrio un error en la conexión, intentalo mas tarde'
                    });
                    deffered.resolve();
            }); 
            return deffered.promise;
        }
        Pagos.data = function () {
            return data;
        };

        return Pagos;

    })
.factory('PushNotifications', function ($rootScope) {


    var Push = {};
    var productos = JSON.parse(window.localStorage['carrito'] || '[]');


    Push.initNotifications = function () {
        var push = PushNotification.init({
            android: {
                senderID: "375972812186"
            },
            ios: {
                alert: "true",
                badge: true,
                sound: 'true'
            },
            windows: {}

        });

        push.on('registration', function (data) {

            window.localStorage.setItem('token', data.registrationId);

            console.log(data.registrationId);
            
            push.setApplicationIconBadgeNumber(function() {
                console.log('success');
            }, function() {
                console.log('error');
            }, 0);
        });

        push.on('notification', function (data) {

            push.setApplicationIconBadgeNumber(function() {
                console.log('success');
            }, function() {
                console.log('error');
            }, 0);


            //$rootScope.consulta = data.additionalData.consulta;
            //console.log($rootScope.consulta);
/*
            if ($rootScope.consulta.status == 1) { //nuevo
                window.localStorage.setItem('consulta', JSON.stringify($rootScope.consulta));

                $rootScope.$broadcast('push');
            }
            */
            console.log(data);
            if(data.additionalData.additionalData=="pedido_semanal"){
                $rootScope.getPedidosSemanales();
            }
            

            /*
            console.log(data.message);
            console.log(data.title);
            console.log(data.count);
            console.log(data.sound);
            console.log(data.image);
            console.log(data.additionalData);
            */

        });

        push.on('error', function (e) {
            console.log(e.message);
        });

    };


    return Push;

});